import time

class Finch:
    """ API for controling a Finch robot. """

    def __init__(self):
        self.start = time.time() - 1

    def _debug(self, text):
        offset = time.time() - self.start
        print "{0:.4}\t{1}".format(offset, text)

    def close(self):
        """ Closes the connection to the Finch. """
        self._debug("close()")

    def halt(self):
        """ Set all motors and LEDs to off. """
        self._debug("halt()")

    def led(self, *args):
        """ Control three LEDs (orbs).

            Hex triplet string: led('#00FF8B') or
            0-255 RGB values: led(0, 255, 139) """
        self._debug("led" + str(args))

    def wheels(self, left, right):
        """ Controls the left and right wheels.

        Values must range from -1.0 (full throttle reverse) to
        1.0 (full throttle forward). Use (0.0,0.0) to stop. """
        text = "wheels({0}, {1})".format(left, right)
        self._debug(text)

    def buzzer(self, duration, frequency):
        """ Outputs sound. Does not wait until a note is done beeping.

        duration - duration to beep, in seconds (s).
        frequency - integer frequency, in hertz (HZ). """
        text = "buzzer({0}, {1})".format(duration, frequency)
        self._debug(text)

    def temperature(self):
        """ Returns temperature in degrees Celsius. """
        self._debug("temperature()")

    def light(self):
        """ Get light sensor readings. The values ranges from 0.0 to 1.0.

            returns - a tuple(left, right) of two real values """
        self._debug("light()")

    def obstacle(self):
        """ Get obstacle sensor readings.

            returns - a tuple(left,right) of two boolean values """
        self._debug("obstacle()")

    def _convert_raw_accel(self, a):
        """ Converts raw acceleration obtained from the hardware into G's. """
        self._debug("_convert_raw_accel(" + str(a) + ")")

    def acceleration(self):
        """ Returns (x, y, z, tap, shake).
            x, y, and z are the acceleration readings in units of G's and range from -1.5 to 1.5.
            When the finch is horizontal, z is close to 1; x and y are close to 0.
            When the finch stands on its tail, y and z are close to 0; x is close to -1.
            When the finch is held with its left wing down, x and z are close to 0; y is close to 1.
            tap and shake are boolean values; true if the correspondig event has happened. """
        self._debug("acceleration()")
